#! /usr/bin/env python
# -*- Mode: Python -*-
# -*- coding: ascii -*-

"""
RR_BonePin.py takes the selected items in Layout and holds them in
place. This is useful if parent items need to be moved without affecting
the position of their child objects.
"""

__author__     = "Ryan Roye"
__date__       = "July 24 2014"
__copyright__  = "Copyright (C) 2014 Tanadrine Studios"
__version__    = "1.0"
__maintainer__ = "Ryan Roye"
__email__      = "ryanroye@gmail.com"
__status__     = "Utility"
__lwver__      = "11"

try:
    import lwsdk
except ImportError:
    raise Exception("The LightWave Python module could not be loaded.")

import math
	
def getRot():
	items = lwsdk.LWInterfaceInfo().selected_items()
	PivotConvertH = lwsdk.LWItemInfo().param(items[0], lwsdk.LWIP_ROTATION, 0)[0] #returns H rotation at frame 0 in radians
	PivotConvertP = lwsdk.LWItemInfo().param(items[0], lwsdk.LWIP_ROTATION, 0)[1] #returns P rotation at frame 0 in radians
	PivotConvertB = lwsdk.LWItemInfo().param(items[0], lwsdk.LWIP_ROTATION, 0)[2] #returns B rotation at frame 0 in radians
	PivotConvertH = (PivotConvertH*180/math.pi) # Converts radians to degrees
	PivotConvertP = (PivotConvertP*180/math.pi)
	PivotConvertB = (PivotConvertB*180/math.pi)
	RotatePivotValues = []
	RotatePivotValues.append(PivotConvertH)
	RotatePivotValues.append(PivotConvertP)
	RotatePivotValues.append(PivotConvertB)
	return RotatePivotValues
	#invoke --->  myvar = getRot()  ---> myvar[0]

	
#SCRIPT

#Gather Items

items = lwsdk.LWInterfaceInfo().selected_items()

#With Items gathered, for loop goes through each selected item to constrain them to Nulls labeled "RR_BonePin_(boneID)"
for item in lwsdk.LWInterfaceInfo().selected_items():
	lwsdk.command("SelectItem " + lwsdk.itemid_to_str(item)) #Select items 1 by 1
	lwsdk.command("Generic_Store_Selected")
	lwsdk.command("AddNull RR_BonePin_" + lwsdk.itemid_to_str(item)) #Make null same name as item so it can be tracked
	#Color the newly created null and give it a bone display
	lwsdk.command("ItemColor 14")
	
	lwsdk.command("AddBone PinDisplay")
	lwsdk.command("ItemColor 14")
	lwsdk.command("ItemLock")
	lwsdk.command("BoneType 1")
	lwsdk.command("ItemIconScale 0.5")
	lwsdk.command("FirstItem")
	lwsdk.command("SelectParent")
	#END COLOR/Display setup
	lwsdk.command("Generic_Assign_Same_As_Position")
	lwsdk.command("Generic_Assign_Same_As_Rotation")
	
	lwsdk.command("RefreshNow")
	lwsdk.command("AddPosition 0 0 0")
	lwsdk.command("AddRotation 0 0 0")
	lwsdk.command("RefreshNow")
	
	lwsdk.command("Generic_Clear_Position")
	lwsdk.command("Generic_Clear_Rotation")
	lwsdk.command("RefreshNow")
	
	lwsdk.command("Generic_Store_Selected")
	lwsdk.command("SelectItem " + lwsdk.itemid_to_str(item)) #Re-select the item (determined by loop #)
	
	lwsdk.command("Generic_Assign_Same_As_Position")
	lwsdk.command("Generic_Assign_Same_As_Rotation")
	
	lwsdk.command("XTransform 1, 0")
	lwsdk.command("YTransform 1, 0")
	lwsdk.command("ZTransform 1, 0")
	lwsdk.command("RefreshNow")
	RotationOffset = getRot()
	RotationOffset[0] = RotationOffset[0]*-1 #Invert the values to offset
	RotationOffset[1] = RotationOffset[1]*-1
	RotationOffset[2] = RotationOffset[2]*-1
	lwsdk.command("HTransform " + "1" + " " + str(RotationOffset[0]))
	lwsdk.command("PTransform " + "1" + " " + str(RotationOffset[1]))
	lwsdk.command("BTransform " + "1" + " " + str(RotationOffset[2]))
	

ServerTagInfo = [
                    ( "RR_BonePin", lwsdk.SRVTAG_USERNAME | lwsdk.LANGID_USENGLISH ),
                    ( "RR_BonePin", lwsdk.SRVTAG_BUTTONNAME | lwsdk.LANGID_USENGLISH ),
                    ( "Utilities/Python", lwsdk.SRVTAG_MENU | lwsdk.LANGID_USENGLISH )
                ]